@@ -2,11 +2,14 @@ import re
 import os
 import json
 import urllib
-import urllib3
-import requests
 import logging
 
+from time import sleep
 from http.cookiejar import MozillaCookieJar
+
+import urllib3
+import requests
+
 from requests.exceptions import RequestException
 
 
@@ -81,7 +84,7 @@ class RequestHelper:
         try:
             response = session.post(url, data=data_urlencoded, headers=self.stdHeader, verify=self.verify, timeout=60)
         except RequestException as error:
-            raise ConnectionError("Connection error: %s" % str(error)) from None
+            raise ConnectionError(f"Connection error: {str(error)}") from None
 
         if cookie_jar_path is not None:
             for cookie in session.cookies:
@@ -110,7 +113,7 @@ class RequestHelper:
         try:
             response = session.get(url, headers=self.stdHeader, verify=self.verify, timeout=60)
         except RequestException as error:
-            raise ConnectionError("Connection error: %s" % str(error)) from None
+            raise ConnectionError(f"Connection error: {str(error)}") from None
 
         if cookie_jar_path is not None:
             session.cookies.save(ignore_discard=True, ignore_expires=True)
@@ -124,6 +127,11 @@ class RequestHelper:
         @param data: The optional data is added to the POST body.
         @return: The JSON response returned by the Moodle system, already
         checked for errors.
+
+        As discussed in issue #131, it occurs, that the POST-REQUEST fails, which results automatically in a failure.
+        In the following lines of code, the Post-Request will be retried.
+        The loop terminates, since in every loop the variable i is incremented and goes strictly in the direction of
+        the variable maxretries or the loop breaks if the response is successful.
         """
 
         if self.token is None:
@@ -132,17 +140,33 @@ class RequestHelper:
         data_urlencoded = self._get_POST_DATA(function, self.token, data)
         url = self._get_REST_POST_URL(self.url_base, function)
 
-        try:
-            response = requests.post(url, data=data_urlencoded, headers=self.stdHeader, verify=self.verify, timeout=timeout)
-        except RequestException as error:
-            raise ConnectionError("Connection error: %s" % str(error)) from None
+        error_ctr = 0
+        maxretries = 5
+        while True:
+            try:
+                response = requests.post(
+                    url, data=data_urlencoded, headers=self.stdHeader, verify=self.verify, timeout=timeout
+                )
+                break
+            except (requests.ConnectionError, requests.Timeout) as error:
+                # We treat requests.ConnectionErrors here specially, since they normally mean, that something went rong,
+                # which could be fixed by a restart.
+                error_ctr += 1
+                if error_ctr < maxretries:
+                    logging.debug("The %sth Connection Error occurred, retrying. %s", error_ctr, str(error))
+                    sleep(1)
+                    continue
+                else:
+                    raise ConnectionError(f"Connection error: {error}") from None
+            except RequestException as error:
+                raise ConnectionError(f"Connection error: {error}") from None
 
         json_result = self._initial_parse(response)
         if self.log_responses and function not in ['tool_mobile_get_autologin_key']:
             with open(self.log_responses_to, 'a', encoding='utf-8') as response_log_file:
-                response_log_file.write('URL: {}\n'.format(response.url))
-                response_log_file.write('Function: {}\n\n'.format(function))
-                response_log_file.write('Data: {}\n\n'.format(data))
+                response_log_file.write(f'URL: {response.url}\n')
+                response_log_file.write(f'Function: {function}\n\n')
+                response_log_file.write(f'Data: {data}\n\n')
                 response_log_file.write(json.dumps(json_result, indent=4, ensure_ascii=False))
                 response_log_file.write('\n\n\n')
 
@@ -155,7 +179,7 @@ class RequestHelper:
         @params: The necessary parameters for a REST URL
         @return: A formatted URL
         """
-        url = '%swebservice/rest/server.php?moodlewsrestformat=json&wsfunction=%s' % (url_base, function)
+        url = f'{url_base}webservice/rest/server.php?moodlewsrestformat=json&wsfunction={function}'
 
         return url
 
@@ -186,14 +210,14 @@ class RequestHelper:
         """
         try:
             response = requests.post(
-                '%slogin/token.php' % (self.url_base),
+                f'{self.url_base}login/token.php',
                 data=urllib.parse.urlencode(data),
                 headers=self.stdHeader,
                 verify=self.verify,
                 timeout=60,
             )
         except RequestException as error:
-            raise ConnectionError("Connection error: %s" % str(error)) from None
+            raise ConnectionError(f"Connection error: {str(error)}") from None
 
         return self._initial_parse(response)
 
@@ -203,9 +227,9 @@ class RequestHelper:
         if response.status_code != 200:
             raise RequestRejectedError(
                 'An Unexpected Error happened on side of the Moodle System!'
-                + (' Status-Code: %s' % str(response.status_code))
-                + ('\nHeader: %s' % response.headers)
-                + ('\nResponse: %s' % response.text)
+                + f' Status-Code: {str(response.status_code)}'
+                + f'\nHeader: {response.headers}'
+                + f'\nResponse: {response.text}'
             )
 
     def get_simple_moodle_version(self) -> float:
@@ -216,11 +240,11 @@ class RequestHelper:
                  parsed from the change-log
         """
 
-        url = '%slib/upgrade.txt' % (self.url_base)
+        url = f'{self.url_base}lib/upgrade.txt'
         try:
             response = requests.get(url, headers=self.stdHeader, verify=self.verify, timeout=60)
         except RequestException as error:
-            raise ConnectionError("Connection error: %s" % str(error)) from None
+            raise ConnectionError(f"Connection error: {str(error)}") from None
 
         self._check_response_code(response)
 
@@ -246,13 +270,13 @@ class RequestHelper:
         # Try to parse the JSON
         try:
             response_extracted = response.json()
-        except ValueError as error:
+        except ValueError:
             raise RequestRejectedError('The Moodle Mobile API does not appear to be available at this time.') from None
         except Exception as error:
             raise RequestRejectedError(
                 'An Unexpected Error occurred while trying'
                 + ' to parse the json response! Moodle'
-                + ' response: %s.\nError: %s' % (response.text, error)
+                + f' response: {response.text}.\nError: {error}'
             ) from None
         # Check for known errors
         if 'error' in response_extracted:
@@ -264,8 +288,8 @@ class RequestHelper:
 
             raise RequestRejectedError(
                 'The Moodle System rejected the Request.'
-                + (' Details: %s (Errorcode: %s, ' % (error, errorcode))
-                + ('Stacktrace: %s, Debuginfo: %s, Reproductionlink: %s)' % (stacktrace, debuginfo, reproductionlink))
+                + f' Details: {error} (Errorcode: {errorcode}, '
+                + f'Stacktrace: {stacktrace}, Debuginfo: {debuginfo}, Reproductionlink: {reproductionlink})'
             )
 
         if 'exception' in response_extracted:
@@ -275,12 +299,13 @@ class RequestHelper:
 
             if errorcode == 'invalidtoken':
                 raise RequestRejectedError(
-                    'Your Moodle token has expired. To create a new one run "moodle-dl -nt -u USERNAME -pw PASSWORD" or "moodle-dl -nt -sso"'
+                    'Your Moodle token has expired.'
+                    + ' To create a new one run "moodle-dl -nt -u USERNAME -pw PASSWORD" or "moodle-dl -nt -sso"'
                 )
 
             raise RequestRejectedError(
                 'The Moodle System rejected the Request.'
-                + ' Details: %s (Errorcode: %s, Message: %s)' % (exception, errorcode, message)
+                + f' Details: {exception} (Errorcode: {errorcode}, Message: {message})'
             )
 
         return response_extracted
@@ -292,7 +317,9 @@ class RequestHelper:
         @returns: the url encoded data
         """
 
-        def recursion(data, base=[]):
+        def recursion(data, base=None):
+            if base is None:
+                base = []
             pairs = []
 
             for key, value in data.items():
@@ -303,10 +330,10 @@ class RequestHelper:
                     new_pair = None
                     if len(new_base) > 1:
                         first = urllib.parse.quote(new_base.pop(0))
-                        rest = map(lambda x: urllib.parse.quote(x), new_base)
-                        new_pair = '%s[%s]=%s' % (first, ']['.join(rest), urllib.parse.quote(str(value)))
+                        rest = map(urllib.parse.quote, new_base)
+                        new_pair = f"{first}[{']['.join(rest)}]={urllib.parse.quote(str(value))}"
                     else:
-                        new_pair = '%s=%s' % (urllib.parse.quote(str(key)), urllib.parse.quote(str(value)))
+                        new_pair = f'{urllib.parse.quote(str(key))}={urllib.parse.quote(str(value))}'
                     pairs.append(new_pair)
             return pairs
 
