@@ -16,7 +16,7 @@ import getpass
 from typing import List, Optional
 from colorama import init
 
-import readchar
+import moodle_dl.utils.readchar as readchar
 
 
 terminal = os.getenv('TERM')
@@ -168,11 +168,9 @@ def select(
                 printable_option = printable_option[: (console_columns - 2)] + '..'
 
             if i not in caption_indices:
-                print(
-                    '\033[K{}{}'.format(selected_prefix if i == selected_index else deselected_prefix, printable_option)
-                )
+                print(f'\033[K{selected_prefix if i == selected_index else deselected_prefix}{printable_option}')
             elif i in caption_indices:
-                print('\033[K{}{}'.format(caption_prefix, printable_option))
+                print(f'\033[K{caption_prefix}{printable_option}')
 
         if data_bottom != len(options):
             print(f'{len(options) - data_bottom} more lines below...\033[K')
@@ -317,7 +315,7 @@ def select_multiple(
                     prefix = deselected_ticked_prefix
                 else:
                     prefix = deselected_unticked_prefix
-            print('\033[K{}{}'.format(prefix, printable_option))
+            print(f'\033[K{prefix}{printable_option}')
 
         if data_bottom == len(options):
             # we do not need to print "x more lines below...", instead we print the confirm label or an error
@@ -429,19 +427,20 @@ def prompt_yes_or_no(
             is_yes = not is_yes
             is_selected = True
             current_message = yes_text if is_yes else no_text
-        elif keypress in DefaultKeys.delete:
-            if current_message:
-                current_message = current_message[:-1]
         elif keypress in DefaultKeys.interrupt:
             raise KeyboardInterrupt
         elif keypress in DefaultKeys.confirm:
             if is_selected:
                 break
-        elif keypress in DefaultKeys.tab:
-            if is_selected:
-                current_message = yes_text if is_yes else no_text
         elif keypress is not None:
-            current_message += keypress
+            if keypress in DefaultKeys.tab:
+                pass
+            elif keypress in DefaultKeys.delete:
+                if current_message:
+                    current_message = current_message[:-1]
+            else:
+                current_message += keypress
+
             match_yes = yes_text
             match_no = no_text
             match_text = current_message
@@ -457,6 +456,9 @@ def prompt_yes_or_no(
                 is_yes = True
             else:
                 is_selected = False
+
+            if keypress in DefaultKeys.tab and is_selected:
+                current_message = yes_text if is_yes else no_text
         print()
     print('\033[K\n\033[K\n\033[K\n\033[3A')
     return is_selected and is_yes
